<template>
    <div class="tree-table-container">
        <div class="drag-box" ref="drag-box">
            <div class="drag-left">
                <!--左侧div内容-->
                <div class="common-tree-container">
                    <div class="common-tree-title">
                        <i class="el-icon-menu" /> 组织目录
                    </div>
                    <div class="common-tree-content">
                        <el-tree highlight-current :data="orgTreeList" default-expand-all :props="defaultProps"
                            @node-click="handleNodeClick" :expand-on-click-node="false" />
                    </div>
                </div>
            </div>
            <div class="drag-resize" title="收缩侧边栏">⋮</div>
            <div class="drag-mid">
                <!--右侧div内容-->
                <div class="common-table-container">
                    <div class="bbsl-common-page">
                        <div class="bbsl-table-search">
                            <el-form v-model="queryParam" label-width="auto">
                                <el-row :gutter="10">
                                    <el-col :span="5">
                                        <el-form-item label="姓名">
                                            <el-input v-model="querys[0].value" clearable placeholder="请输入姓名" />
                                        </el-form-item>
                                    </el-col>
                                    <el-col :span="19">
                                        <el-button type="primary" icon="el-icon-search"
                                            @click="handleSearch">搜索</el-button>
                                        <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                                        <el-button type="warning" icon="el-icon-download" @click="downFile"
                                            >导出</el-button>
                                        <el-upload class="upload" :action="actionUrl +
                                            '/manager/duty/member/importExcel'
                                            " :data="{ orgId: currentTreeNode.id }" :show-file-list="false"
                                            :before-upload="beforeUpload" :on-success="handleAvatarSuccess"
                                            :on-error="handleAvatarError" :headers="header"
                                            :disabled="!currentTreeNode || (currentTreeNode.id === '431105377073918469')">
                                            <el-button type="success"
                                                :disabled="!currentTreeNode || (currentTreeNode.id === '431105377073918469')"
                                                icon="el-icon-upload2">导入</el-button>
                                        </el-upload>
                                        <el-button type="warning" icon="el-icon-download"
                                            @click="downModel">模板下载</el-button>
                                    </el-col>
                                </el-row>
                            </el-form>
                        </div>
                        <div ref="contentPanel" class="bbsl-table-content">
                            <div ref="btnPanel" class="bbsl-btn-content">
                                <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
                                <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
                                    <el-button slot="reference" :disabled="!multipleSelection.length"
                                        icon="el-icon-delete" type="danger" style="margin-left: 10px">删除</el-button>
                                </el-popconfirm>
                            </div>
                            <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
                                :style="{ width: '100%' }" :max-height="tableMaxHeight"
                                :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
                                @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
                                <el-table-column type="selection" width="55" />
                                <el-table-column type="index" width="55" label="序号" />
                                <!-- <el-table-column prop="code" label="编号" show-overflow-tooltip /> -->
                                <el-table-column prop="name" width="100" label="姓名" />
                                <el-table-column prop="sex" width="80" label="性别" />
                                <el-table-column prop="iswp" width="80" label="是否外派" />
                                <el-table-column prop="post" min-width="120" label="职位" />
                                <!-- <el-table-column label="执法仪" show-overflow-tooltip>
                  <template
                    slot-scope="scope"
                  >
                  {{scope.row.deviceCode}}
                  </template>
</el-table-column> -->
                                <el-table-column prop="jobName" min-width="120" label="岗位" show-overflow-tooltip />
                                <el-table-column prop="phone" width="120" label="联系电话">
                                    <template v-slot="{ row }">
                                        {{ row.phone.replace(/(\d{3})\d{5}(\d{3})/, "$1*****$2") }}
                                    </template>
                                </el-table-column>
                                <el-table-column prop="orgName" label="所属部门" width="150"/>
                                <!-- <el-table-column prop="cmgtDutyTeam.name" label="所属小组" show-overflow-tooltip />
                <el-table-column prop="deviceCodeName" label="执法仪" show-overflow-tooltip /> -->
                                <el-table-column prop="createTime" min-width="150" label="创建时间" show-overflow-tooltip />
                            </el-table>
                            <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
                                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                                :page-size="queryParam.pageBean.pageSize"
                                layout="total, sizes, prev, pager, next, jumper" :total="total"
                                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <team-member-manage-dialog :deviceList="deviceList" ref="formModal" />
    </div>
</template>

<script>
import { dragControllerDiv } from '@/mixins/dragControllerDiv'
import { TableMixin } from '@/mixins/tableMixin'
import TeamMemberManage from '@/api/manager/duty/teamMemberManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import TeamMemberManageDialog from '@/views/Manage/duty/components/TeamMemberManageDialog'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import { mapState } from 'vuex'
import CommonApi from '@/views/Manage/CommonApi.js'
export default {
    name: 'TeamMemberManage',
    components: {
        TeamMemberManageDialog
    },
    mixins: [TableMixin],
    data() {
        return {
            defaultProps: {
                value: 'id',
                label: 'name',
                parentId: 'parentId',
                code: 'code',
                children: 'children'
            },
            url: {
                delete: '/manager/duty/member/'
            },
            querys: [
                {
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: 'm.name_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'IN',
                    parentGroup: '',
                    property: 'team_id_',
                    relation: 'AND',
                    value: ''
                },
                {
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'm.org_id_',
                    relation: 'AND',
                    value: ''
                }
            ],
            StshowFormDias: false,
            posts: [],
            teams: [],
            depts: [],
            currentTreeNode: '',
            deviceList: [], // 执法仪列表
            actionUrl: '',
            orgTreeList: []
        }
    },
    computed: mapState({
        header: state => {
            return {
                Authorization: `Bearer ${state.login.currentUser.token}`
            }
        }
    }),
    created() {
        this.loadOrg()
        this.actionUrl = window.context.portal
        // this.posts = dictContracts.getDictItemsFromCache('cmgt_post')
        this.getDeviceCode()
    },
    mounted() {
        dragControllerDiv()
    },
    methods: {
        loadOrg() {
            CommonApi.getAllOrgTree(res => {
                this.orgTreeList = res.data
            })
        },
        // 获取执法记录仪信息
        getDeviceCode() {
            let obj = {
                groupRelation: 'AND',
                groupTree: {},
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    showTotal: true
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'p.code_',
                        relation: 'AND',
                        value: 'ydzfjly'
                    }
                ]
            }
            TeamMemberManage.getDeviceInfo(obj, res => {
                console.log(res)
                this.deviceList = res.rows
            })
        },
        renderTreeNode(data) {
            if (data != null && data.length > 0) {
                var orgNames = new Set()
                data.forEach(item => {
                    orgNames.add(item.orgName)
                })
                var treeNodes = []
                orgNames.forEach(item => {
                    var pid = []
                    var child = data.filter(c => {
                        if (c.orgName === item) {
                            pid.push(c.id)
                            return c
                        }
                    })
                    var node = {
                        id: pid.join(','),
                        name: item,
                        children: child
                    }
                    treeNodes.push(node)
                })
                this.depts = treeNodes
            } else {
                this.depts = []
            }
        },
        handleNodeClick(data) {
            // 点击分类树节点
            this.currentTreeNode = data
            this.loadData(1)
        },
        // 重置
        clearQuerys() {
            this.querys[0].value = ''
            this.querys[1].value = null
            this.querys[2].value = null
            this.currentTreeNode = ''
        },
        // 获取list
        loadData(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.loading = true
            this.tableData = []
            this.queryParam.querys = []
            if (this.querys[0].value) {
                this.queryParam.querys.push(this.querys[0])
            }
            if (this.currentTreeNode) {
                // if (this.currentTreeNode.dataType === 'ORG') {
                //     this.querys[2].value = this.currentTreeNode.id
                //     this.queryParam.querys.push(this.querys[2])
                // } else {
                //     this.querys[1].value = this.currentTreeNode.id
                //     this.queryParam.querys.push(this.querys[1])
                // }
                this.querys[2].value = this.currentTreeNode.id
                this.queryParam.querys.push(this.querys[2])
            }
            TeamMemberManage.pageQuery(this.queryParam).then(res => {
                const {
                    data: { total, rows }
                } = res
                this.total = total
                this.tableData = rows
                this.tableData.forEach(item => {
                    this.deviceList.forEach(it => {
                        if (item.deviceCode === it.code) {
                            item.deviceCodeName = it.name
                        }
                    })
                })
                this.$set(this.tableData)
                this.loading = false
            })
        },
        // 修改
        handleUpdate(row) {
            this.$refs.formModal.Update(row)
        },
        // add
        handleAdd() {
            this.$refs.formModal.add(this.currentTreeNode)
        },
        closeStshowForm() {
            this.StshowFormDias = false
        },
        downFile() {
            TeamMemberManage.exportMember(
                {
                    ...this.queryParam,
                    pageBean: {
                        pageSize: -1
                    }
                },
                () => { }
            )
        },
        // 文件上传前
        beforeUpload() {
            this.loading = true
        },
        //上传成功
        handleAvatarSuccess(res, file) {
            //提示
            this.$notify({
                type: 'success',
                message: this.$t('导入成功!'),
                duration: 2000
            })
            this.loadData() //调用用页面查询接口，刷新数据
        },
        //上传失败
        handleAvatarError(err, file, fileList) {
            let data = JSON.parse(err.message)
            let msg = data.message ? data.message : '导入失败！'
            //提示
            this.$notify({
                type: 'error',
                message: this.$t(msg),
                duration: 2000
            })
            this.loading = false
        },
        // 模板下载
        downModel() {
            window.open(
                this.actionUrl + '/manager/duty/member/downModel',
                '_blank'
            )
        }
    }
}
</script>
<style lang="scss" scoped>
.upload {
    display: inline-block;
    width: fit-content;
    margin: 0 10px;
}

.type-tag {
    margin: 0 2px;
}
</style>
